58#include "bicgstab_kernel.cl.h"
80 "bicgstab_update_p_kernel", &
err);
90 const int nb = ((*n) + 256 - 1) / 256;
120 const int nb = ((*n) + 256 - 1) / 256;
127 "bicgstab_product_and_norm_kernel",
147 for (
i = 0;
i <
nb;
i++) {
174 const int nb = ((*n) + 256 - 1) / 256;
181 "bicgstab_part1_kernel", &
err);
202 for (
i = 0;
i <
nb;
i++) {
219 void *s,
void *t,
void *f,
void *mult,
235 const int nb = ((*n) + 256 - 1) / 256;
242 "bicgstab_part2_kernel", &
err);
268 for (
i = 0;
i <
nb;
i++) {
real_xp opencl_bicgstab_part1(void *s, void *r, void *v, void *mult, real *alpha, int *n, cl_command_queue cmd_queue)
void opencl_bicgstab_part2(void *x, void *r, void *p_hat, void *s_hat, void *s, void *t, void *f, void *mult, real *alpha, real *omega, real_xp *res, int *n, cl_command_queue cmd_queue)
void opencl_bicgstab_product_and_norm(void *a, void *b, void *mult, real_xp *res, int *n, cl_command_queue cmd_queue)
static opencl_buffer_t redbuf
void opencl_bicgstab_update_p(void *p, void *r, void *v, real *beta, real *omega, int *n, cl_command_queue cmd_queue)
void opencl_buffer_reserve(opencl_buffer_t *buf, size_t size)
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
__global__ void const T *__restrict__ x
void opencl_kernel_jit(const char *kernel, cl_program *program)
#define OPENCL_BUFFER_INIT